@@ -8,6 +8,7 @@ from arangodb.query.advanced import Query, Traveser
 from arangodb.query.utils.document import create_document_from_result_dict
 from arangodb.query.simple import SimpleQuery
 from arangodb.transaction.controller import Transaction, TransactionController
+from arangodb.user import User
 
 
 client = Client(hostname='localhost')
@@ -806,5 +807,48 @@ class TransactionTestCase(ExtendedTestCase):
 
         self.assertEqual(doc.foo, new_foo_value)
 
+
+class IndexTestCase(ExtendedTestCase):
+    def setUp(self):
+
+        self.database_name = 'testcase_index_123'
+        self.db = Database.create(name=self.database_name)
+
+        self.operating_collection = 'foo_test'
+        self.test_1_col = Collection.create(name=self.operating_collection)
+
+    def tearDown(self):
+        Collection.remove(name=self.operating_collection)
+        Database.remove(name=self.database_name)
+
+
+class UserTestCase(ExtendedTestCase):
+    def setUp(self):
+
+        self.database_name = 'testcase_user_123'
+        self.db = Database.create(name=self.database_name)
+
+
+    def tearDown(self):
+        Database.remove(name=self.database_name)
+
+    def test_get_root(self):
+
+        root = User.get(name='root')
+
+        self.assertEqual(root.name, 'root')
+
+    def test_create_and_delete_user_foo(self):
+
+        user_name = 'foo'
+
+        User.create(name=user_name, password='extra_key')
+
+        foo_user = User.get(name=user_name)
+
+        self.assertEqual(foo_user.name, user_name)
+
+        User.remove(name=user_name)
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
